@@ -6,8 +6,8 @@
 # by users to get/set plate data.
 
 #' Plate type
-#' 
-#' Get the type of a ddPCR plate. 
+#'
+#' Get the type of a ddPCR plate.
 #' \href{https://github.com/daattali/ddpcr#advanced-topic-3-creating-new-plate-types}{See the README} for more
 #' information on plate types.
 #' @param plate A ddPCR plate
@@ -15,12 +15,12 @@
 #' show all inherited (implicit) types as well.
 #' @return A character vector with the plate type(s).
 #' @seealso \code{\link[ddpcr]{plate_types}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir(), type = plate_types$fam_positive_pnpp)
 #' type(plate)
 #' type(plate, TRUE)
-#' } 
+#' }
 #' @export
 type <- function(plate, all = FALSE) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
@@ -32,7 +32,7 @@ type <- function(plate, all = FALSE) {
 }
 
 #' Plate data (droplets data)
-#' 
+#'
 #' The main piece of information in every ddPCR plate is the droplets data,
 #' which contains the fluorescence intensities for every single droplet in
 #' every well. After a ddPCR plate gets analyzed, this data also includes the
@@ -44,11 +44,11 @@ type <- function(plate, all = FALSE) {
 #' the assigned cluster of each droplet.
 #' @seealso \code{\link[ddpcr]{plate_meta}}\cr
 #' \code{\link[ddpcr]{plot.ddpcr_plate}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' plate_data(plate)
-#' } 
+#' }
 #' @export
 plate_data <- function(plate) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
@@ -56,7 +56,7 @@ plate_data <- function(plate) {
 }
 
 #' Overwrite the plate data
-#' 
+#'
 #' When creating custom analysis steps for new plate types, it is often necessary
 #' to set the plate data with new data, especially when assigning new clusters
 #' to the plate droplets.
@@ -71,12 +71,12 @@ plate_data <- function(plate) {
 }
 
 #' Plate status
-#' 
+#'
 #' The status of a plate corresponds to the number of analysis steps that have
 #' taken place. A plate that has been initialized but has not yet been analyzed
 #' at all has status 1.\cr\cr
 #' If you add custom analysis steps to a new plate type, you should make sure
-#' to update the status of the plate after each step. You can use 
+#' to update the status of the plate after each step. You can use
 #' \code{\link[ddpcr]{check_step}} to ensure that the plate is at an appropriate
 #' status before beginning each step.
 #' @seealso \code{\link[ddpcr]{steps}}\cr
@@ -100,7 +100,7 @@ status <- function(plate) {
 }
 
 #' Is a plate empty?
-#' 
+#'
 #' A plate is considered empty if it has not yet been fully initialized, and thus
 #' its status is 0.
 #' @seealso \code{\link[ddpcr]{status}}
@@ -111,12 +111,12 @@ is_empty_plate <- function(plate) {
 }
 
 #' Is the analysis complete?
-#' 
+#'
 #' Check if a ddPCR plate has been fully analyzed or if there are remaining steps.
-#' 
+#'
 #' @param plate A ddPCR plate
 #' @return \code{TRUE} if the plate's analysis has been fully carried out;
-#' \code{FALSE} otherwise. 
+#' \code{FALSE} otherwise.
 #' @seealso \code{\link[ddpcr]{status}}\cr
 #' \code{\link[ddpcr]{analyze}}
 #' @export
@@ -124,39 +124,39 @@ analysis_complete <- function(plate) {
   status(plate) == length(steps(plate))
 }
 
-#' Plate metadata 
+#' Plate metadata
 #'
 #' The metadata is a collection of variables that describe each well in the plate.
 #' The metadata of an unanalyzed plate only contains basic information about each
-#' well, such as the sample name, whether the well was used, and the number of 
+#' well, such as the sample name, whether the well was used, and the number of
 #' droplets in the well. Analyzing a plate adds many more variables to the metadata,
-#' such as the number of empty droplets, the number of outliers, the template 
+#' such as the number of empty droplets, the number of outliers, the template
 #' concentration, and more.
-#' 
+#'
 #' @param plate A ddPCR plate
 #' @param only_used If \code{TRUE}, only return metadata for wells that are
 #' used in this plate (wells that have any data)
 #' @return A dataframe containing the plate metadata
 #' @seealso \code{\link[ddpcr]{plate_data}}
 #' \code{\link[ddpcr]{plot.ddpcr_plate}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' plate %>% plate_meta(only_used = TRUE)
 #' plate %>% analyze %>% plate_meta(only_used = TRUE)
-#' } 
+#' }
 #' @export
 plate_meta <- function(plate, only_used = FALSE) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
-  
+
   if (only_used) {
     plate[['plate_meta']] %>% dplyr::filter_(quote(used))
-  } else {  
+  } else {
     plate[['plate_meta']]
   }
 }
 #' Overwrite the plate metadata
-#' 
+#'
 #' When creating custom analysis steps for new plate types, it is often necessary
 #' to add/change variables in the plate metadata.
 #' @param plate A ddPCR plate
@@ -171,19 +171,19 @@ plate_meta <- function(plate, only_used = FALSE) {
 # Arrange the metadata such that the more general variables are near the beginning
 arrange_meta <- function(plate) {
   if ("success" %in% colnames(plate)) {
-    plate %>% dplyr::arrange_(~ desc(used), ~ desc(success), ~ row, ~ col)  
+    plate %>% dplyr::arrange_(~ desc(used), ~ desc(success), ~ row, ~ col)
   } else {
     plate %>% dplyr::arrange_(~ desc(used), ~ row, ~ col)
   }
 }
 
 #' Plate name
-#' 
+#'
 #' Get or set the name of a dataset.
 #' @param plate A ddpcrPlate
 #' @param value New name
 #' @return Plate name
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' name(plate)
@@ -208,7 +208,7 @@ name <- function(plate) {
 }
 
 #' Plate parameters
-#' 
+#'
 #' Every ddPCR plate object has adjustable parameters associated with it.
 #' Each parameter belongs to a category of parameters, and has a unique name.
 #' For example, there are general parameters (category 'GENERAL') that apply to
@@ -217,14 +217,14 @@ name <- function(plate) {
 #' You can either view all parameters of a plate by not providing any arguments,
 #' view all parameters in a category by providing the category, or view the value
 #' of a specific parameter by providing both the category and the parameter name.\cr\cr
-#' 
+#'
 #' Setting new parameter values should only be done by advanced users.
 #' Note that if you change any parameters, you need to re-run the analysis in order
 #' for the parameter changes to take effect.
-#' 
+#'
 #' Tip: it can be easier to visually inspect the parameters by wrapping the
 #' return value in a \code{str()}.
-#' 
+#'
 #' Warning: Do not directly set the GENERAL-X_VAR or GENERAL-Y_VAR parameters.
 #' Instead, use \code{\link[ddpcr]{x_var}} or \code{\link[ddpcr]{y_var}}.
 #' @param plate A ddPCR plate
@@ -235,15 +235,15 @@ name <- function(plate) {
 #' return all parameters in that category. If both a category and a name are provided,
 #' return the value of the specific parameter.
 #' @seealso \code{\link[ddpcr]{x_var}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
-#' 
+#'
 #' # retrieving plate parameters
 #' str(params(plate))
 #' str(params(plate, 'GENERAL'))
 #' params(plate, 'GENERAL', 'RANDOM_SEED')
-#' 
+#'
 #' # setting plate parameters
 #' params(plate, 'GENERAL', 'RANDOM_SEED') <- 10
 #' str(params(plate, 'GENERAL'))
@@ -255,7 +255,7 @@ NULL
 #' @export
 params <- function(plate, category, name) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
-  
+
   res <- plate[['params']]
   if (!missing(category)) {
     res <- res[[category]]
@@ -263,7 +263,7 @@ params <- function(plate, category, name) {
       res <- res[[name]]
     }
   }
-  
+
   res
 }
 #' @rdname params
@@ -276,7 +276,7 @@ params <- function(plate, category, name) {
   if (!is_empty_plate(plate) && status(plate) > step(plate, "INITIALIZE")) {
     plate[['dirty']] <- TRUE
   }
-  
+
   replace <- 'params'
   if (!missing(category)) {
     replace <- c(replace, category)
@@ -284,23 +284,23 @@ params <- function(plate, category, name) {
       replace <- c(replace, name)
     }
   }
-  
+
   plate[[replace]] <- value
   plate
 }
 
 
 #' Potential droplet clusters for a plate type
-#' 
+#'
 #' Each ddPCR plate type has a specific set of potential clusters the droplets
-#' can be assigned to. 
-#' 
+#' can be assigned to.
+#'
 #' \href{https://github.com/daattali/ddpcr#advanced-topic-3-creating-new-plate-types}{See the README} for
 #' more information on plate types.
 #' @param plate a ddPCR plate.
 #' @return A character vector with the names of the clusters supported by the
 #' plate type.
-#' @examples 
+#' @examples
 #' \dontrun{
 #' dir <- sample_data_dir()
 #' new_plate(dir) %>% clusters
@@ -320,7 +320,7 @@ clusters <- function(plate) {
   plate
 }
 #' Get cluster ID by name
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' # see what cluster names exist and their order
@@ -338,7 +338,7 @@ cluster <- function(plate, cluster) {
   res
 }
 #' Get cluster name by ID
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' # see what cluster names exist and their order
@@ -349,27 +349,26 @@ cluster <- function(plate, cluster) {
 #' @keywords internal
 #' @export
 cluster_name <- function(plate, cluster) {
-  cluster %>% as.integer
-  if (cluster < 1 || cluster > plate %>% clusters %>% length) {
-    err_msg(sprintf("invalid cluster number: %s", cluster))
+  if (any(cluster < 1) || any(cluster > plate %>% clusters %>% length)) {
+    err_msg(sprintf("invalid cluster number: %s", paste(cluster, collapse = " ")))
   }
   plate %>% clusters %>% .[cluster]
 }
 
 #' Get unanalyzed cluseter IDs
-#' 
+#'
 #' Get the clusters that have not been considered yet in the analysis. This means
 #' the UNDEFINED cluster (since all droplets begin as UNDEFINED) and also all
 #' clusters that are defined later than the current cluster. The latter is to
 #' ensure that when re-running an analysis step, droplets that were analyzed
 #' in a later step will still be considered for analysis.
-#' 
+#'
 #' @param plate A ddPCR plate
 #' @param current The current cluster ID, which is used to know what clusters
 #' come after
 #' @return All clusters that have not yet been analyzed
 #' @seealso \code{\link[ddpcr]{cluster}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' unanalyzed_clusters(plate, 3)
@@ -391,7 +390,7 @@ unanalyzed_clusters <- function(plate, current) {
 }
 
 #' Analysis steps of a ddPCR plate
-#' 
+#'
 #' Every ddPCR plate type has an ordered set of steps that are run to analyze
 #' the data. You can run all the steps with \code{\link[ddpcr]{analyze}} or
 #' run the analysis step by step with \code{\link[ddpcr]{next_step}}. The order
@@ -402,7 +401,7 @@ unanalyzed_clusters <- function(plate, current) {
 #' used to perform the step.
 #' @seealso \code{\link[ddpcr]{analyze}}\cr
 #' \code{\link[ddpcr]{next_step}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' dir <- sample_data_dir()
 #' new_plate(dir) %>% steps
@@ -421,7 +420,7 @@ steps <- function(plate) {
   plate
 }
 #' Get step ID by step name
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' # see what step names exist and their order
@@ -438,7 +437,7 @@ step <- function(plate, step) {
   res
 }
 #' Get step name by ID
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' # see what step names exist and their order
@@ -449,18 +448,18 @@ step <- function(plate, step) {
 #' @export
 step_name <- function(plate, step) {
   step %<>% as.integer
-  if (step < 1 || step > plate %>% steps %>% length) {
-    err_msg(sprintf("invalid step number: %s", step))
+  if (any(step < 1) || any(step > plate %>% steps %>% length)) {
+    err_msg(sprintf("invalid step number: %s", paste(step, collapse = " ")))
   }
   plate %>% steps %>% names %>% .[step]
 }
 #' Ensure the plate's status is at the right step
-#' 
+#'
 #' Before beginning a step, you can check to make sure the plate is currently
 #' at most one step behind the current step. If the plate is more than one step
 #' behind, an error will be thrown, so that the user will know they need to
 #' run the previous steps.
-#' @examples 
+#' @examples
 #' \dontrun{
 #' dir <- sample_data_dir()
 #' plate <- new_plate(dir)
@@ -469,7 +468,7 @@ step_name <- function(plate, step) {
 #' check_step(plate, 3) # are we ready to start step 3?
 #' plate <- next_step(plate)
 #' status(plate)
-#' check_step(plate, 3) # now are we ready to start step 3?  
+#' check_step(plate, 3) # now are we ready to start step 3?
 #' }
 #' @export
 #' @keywords internal
@@ -482,7 +481,7 @@ check_step <- function(plate, step) {
 #' Does a ddPCR plate have a step with this name?
 #' @param plate A ddPCR plate
 #' @param step A step name
-#' @examples 
+#' @examples
 #' \dontrun{
 #' dir <- sample_data_dir()
 #' plate <- new_plate(dir)
@@ -502,11 +501,11 @@ has_step <- function(plate, step) {
 }
 
 #' Get/set the X/Y variable (dye name)
-#' 
+#'
 #' By default, the dye visualized along the X axis is HEX and the dye visualized
 #' along the Y axis is FAM. You can use these functions to get or set these values
 #' if your plate uses different dyes.
-#' 
+#'
 #' The X/Y variables are simply parameters in the plate, which can also be accessed
 #' or changed using \code{\link[ddpcr]{params}}. You should use these functions
 #' to change the X/Y variable rather than changing the parameters directly.
@@ -514,7 +513,7 @@ has_step <- function(plate, step) {
 #' @param value New dye name
 #' @return Dye name
 #' @seealso \code{\link[ddpcr]{params}}
-#' @examples 
+#' @examples
 #' \dontrun{
 #' plate <- new_plate(sample_data_dir())
 #' x_var(plate)
@@ -540,7 +539,7 @@ y_var <- function(plate) {
 #' @export
 `x_var<-` <- function(plate, value) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
-  
+
   value %<>% make.names
   plate_data(plate) %<>%
     dplyr::rename_(.dots = stats::setNames(x_var(plate), value))
@@ -551,7 +550,7 @@ y_var <- function(plate) {
 #' @export
 `y_var<-` <- function(plate, value) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
-  
+
   value %<>% make.names
   plate_data(plate) %<>%
     dplyr::rename_(.dots = stats::setNames(y_var(plate), value))
@@ -568,4 +567,4 @@ y_var <- function(plate) {
 is_dirty <- function(plate) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
   plate[['dirty']]
-}
\ No newline at end of file
+}
