@@ -3,7 +3,7 @@ context("v174")
 test_that("reading v174 works", {
   dir <- system.file("sample_data", "read_v174", package = "ddpcr")
   plate <- new_plate(dir) 
-  expected_data <- readr::read_csv(file.path(dir, "expected_data.csv"), col_types = "ciii")
+  expected_data <- readr_read_csv(file.path(dir, "expected_data.csv"), col_types = "ciii")
   expect_equal(expected_data, plate_data(plate))
   
   meta <- plate %>% plate_meta(only_used = TRUE)
